# sm-icon-extractor
## Extracts icons from Scrap Mechanic

## Installation
* Install [Python](https://www.python.org/)
* Run `pip3 install sm-icon-extractor`

## Setup
### Configuration
The configuration is read from a file named "sm-icon-extractor.ini" from \~/.config and the current directory (~ = home directory of the current user)
```ini
[Game]
Path=<Path to the Scrap Mechanic installation directory>
```

## Running
To extract all IconMaps, run `sm-icon-extractor`

For more information, run `sm-icon-extractor --help`
